
import GRDB
import GRDBQuery
import Foundation
import SwiftUI

struct NaviBar: View {
    @ObservedObject var paneConnector: PaneConnector

    @Query(RibbonRequest(dir: .prev, groupId: 1)) private var backRibbon: [Ribbon]
    @Query(RibbonRequest(dir: .next, groupId: 1)) private var nextRibbon: [Ribbon]

    @Query(SelectedRibbonRequest()) private var selectedRibbon: [Ribbon]
    @Environment(\.appDatabase) private var appDatabase


    var body: some View {
        VStack {
            HStack {
                // Print("meow navi reloaded back ribbon: \(backRibbon[0])")

                Print("rendering navi")
                Print("dog backRibbon: \(backRibbon)")
                BackArrow()
                    .frame(width: CGFloat(30), height: CGFloat(30))
                    .background(Color(red: 0.1, green: 0.1, blue: 0.1))
                    // .foregroundColor(Color(UIColor(red: 0.30, green: 0.30, blue: 0.30, alpha: 0.4)))
                    .if(paneConnector.hasMoved) { $0.foregroundColor(Color.black) }
                    .if(!paneConnector.hasMoved) { $0.foregroundColor(Color(UIColor(red: 0.30, green: 0.30, blue: 0.30, alpha: 0.4))) }
                    .onTapGesture {
                        Task {
                            var br = backRibbon[0]
                            var sr = selectedRibbon[0]

                            do {
                                if paneConnector.hasMoved {
                                    print("has moved")

                                    let updatedRibbon = try await createUndoState(selectedRibbon: sr,
                                                                                  appDatabase: appDatabase,
                                                                                  paneConnector: paneConnector)
                                    goToRibbon(selectedRibbon: sr,
                                               destRibbon: sr,
                                               appDatabase: appDatabase,
                                               paneConnector: paneConnector,
                                               loading: false)
                                } else {
                                    if backRibbon.count == 0 {
                                        return
                                    }

                                    try await appDatabase.undoRibbon(&sr)

                                    goToRibbon(selectedRibbon: sr,
                                               destRibbon: br,
                                               appDatabase: appDatabase,
                                               paneConnector: paneConnector,
                                               loading: false)
                                }

                            } catch {
                                print("Back Arrow Error info: \(error)")
                            }
                        }
                    }

                ForwardArrow()
                    .frame(width: CGFloat(30), height: CGFloat(30))
                    .background(Color(red: 0.1, green: 0.1, blue: 0.1))
                    .foregroundColor(Color(UIColor(red: 0.30, green: 0.30, blue: 0.30, alpha: 0.4)))
                    .onTapGesture {
                        if nextRibbon.count == 0 {
                            return
                        }

                        Task {
                            var sr = selectedRibbon[0]
                            var nr = nextRibbon[0]
                            try await appDatabase.redoRibbon(&sr)

                            goToRibbon(selectedRibbon: sr,
                                       destRibbon: nr,
                                       appDatabase: appDatabase,
                                       paneConnector: paneConnector,
                                       loading: false)
                        }
                    }
            }
            .cornerRadius(5)
        }
    }
}
